<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;

class RelTipoSangriaService {

	public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function fetchReport($conditions) {
        $params = RelTipoSangriaService::buildQueryParams($conditions);
        return $this->entityManager->getConnection()->fetchAll(self::GET_TIPO_SANGRIA, $params);
    }
    
    private function buildQueryParams($conditions){
        if(array_key_exists('CDFILIAL', $conditions)){
            $conditions['CDFILIAL']  = implode('_', $conditions['CDFILIAL']);
            $conditions['TCDFILIAL'] = NULL;
        } else {
            $conditions['CDFILIAL']  = NULL;
            $conditions['TCDFILIAL'] = 'T';
        }
        if(array_key_exists('CHAVE', $conditions)){
            $conditions['CDTPSANGRIA'] = implode('_', $conditions['CHAVE']);
            $conditions['TCDTPSNGRIA'] = NULL;
        } else {
            $conditions['CDTPSANGRIA'] = NULL;
            $conditions['TCDTPSNGRIA'] = 'T';
        }
        if(array_key_exists('CDTIPORECE', $conditions)){
            $conditions['CDTIPORECE'] = implode('_', $conditions['CDTIPORECE']);
            $conditions['T_TIPORECE'] = NULL;
        } else {
            $conditions['CDTIPORECE'] = NULL;
            $conditions['T_TIPORECE'] = 'T';
        }
        
        if(array_key_exists('IDSANGRIA', $conditions)){
            $conditions['IDSANGRIA'] = $conditions['IDSANGRIA'];
            $conditions['T_IDSANGRIA'] = NULL;
        }else{
            $conditions['IDSANGRIA'] = NULL;
            $conditions['T_IDSANGRIA'] = 'T';
        }
        
        $params = array(
            ':CDFILIAL'    => $conditions['CDFILIAL'],
            ':TCDFILIAL'   => $conditions['TCDFILIAL'],
            ':CDTPSANGRIA' => $conditions['CDTPSANGRIA'],
            ':TCDTPSNGRIA' => $conditions['TCDTPSNGRIA'],
            ':TIPORECE'    => $conditions['CDTIPORECE'],
            ':T_TIPORECE'  => $conditions['T_TIPORECE'],
            ':IDSANGRIA'   => $conditions['IDSANGRIA'][0],
            ':T_IDSANGRIA' => $conditions['T_IDSANGRIA'],
            ':DATAINI'     => $conditions['DTENTRVENDA'][0],
            ':DATAFIN'     => $conditions['DTENTRVENDA'][1]
        );
        return $params;
    }
    
    const GET_TIPO_SANGRIA = "
    SELECT MO.CDFILIAL, FI.NMFILIAL, LO.CDLOJA, LO.NMLOJA, CX.CDCAIXA, CX.NMCAIXA, MO.DTHRINCMOV AS DATA, TR.NMTIPORECE AS TIPORECE,
            MO.VRMOVIVEND AS VALOR, COALESCE(MO.DSOBSSANGRIACX, (TS.CDTPSANGRIA||' - '||TS.NMTPSANGRIA)) AS DESCRICAO, TS.NMTPSANGRIA AS TPSANGRIA, TS.IDSANGRIA AS IDSANGRIA, TR.CDTIPORECE,
            MO.CDFILIAL||' - '||FI.NMFILIAL||' Loja: '||LO.CDLOJA||' - '||LO.NMLOJA||' Caixa: '|| CX.CDCAIXA|| ' - '||CX.NMCAIXA AS GROUPER
    FROM MOVCAIXA MO 
    JOIN FILIAL FI
          ON MO.CDFILIAL = FI.CDFILIAL
    JOIN LOJA LO
          ON MO.CDFILIAL = LO.CDFILIAL
    JOIN CAIXA CX
          ON MO.CDFILIAL = CX.CDFILIAL
           AND MO.CDCAIXA = CX.CDCAIXA
           AND LO.CDLOJA       = CX.CDLOJA
    JOIN TIPORECE TR
          ON MO.CDTIPORECE = TR.CDTIPORECE
     LEFT JOIN TIPOSANGRIA TS
          ON MO.CDTPSANGRIA  = TS.CDTPSANGRIA
           AND MO.CDFILIAL = TS.CDFILIAL
    WHERE MO.IDTIPOMOVIVE = 'G'
            AND MO.DTMOVIMCAIXA BETWEEN :DATAINI AND :DATAFIN
            AND ((INSTR(:CDFILIAL, MO.CDFILIAL  ) > 0) OR (:TCDFILIAL    = 'T'))   
            AND ((INSTR(:CDTPSANGRIA, MO.CDFILIAL||MO.CDTPSANGRIA) > 0) OR (:TCDTPSNGRIA = 'T'))
            AND ((INSTR(:TIPORECE, TR.CDTIPORECE) > 0) OR (:T_TIPORECE = 'T')) 
            AND ((INSTR(:IDSANGRIA, TS.IDSANGRIA) > 0) OR (:T_IDSANGRIA = 'T'))   
    ORDER BY MO.CDFILIAL, LO.CDLOJA, CX.CDCAIXA, TS.CDTPSANGRIA, MO.DTMOVIMCAIXA
    ";   
 
}

